summaryrefslogtreecommitdiffstats
path: root/knode
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:50 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:50 -0600
commit9cc13dcbb01a96c9e60a07ca63c61d24b374f50d (patch)
treeab537a329b9613e11dce8195761f93ffe82aed24 /knode
parent3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12 (diff)
downloadtdepim-9cc13dcbb01a96c9e60a07ca63c61d24b374f50d.tar.gz
tdepim-9cc13dcbb01a96c9e60a07ca63c61d24b374f50d.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12.
Diffstat (limited to 'knode')
-rw-r--r--knode/articlewidget.cpp48
-rw-r--r--knode/headerview.cpp12
-rw-r--r--knode/knaccountmanager.cpp10
-rw-r--r--knode/knarticle.cpp2
-rw-r--r--knode/knarticle.h2
-rw-r--r--knode/knarticlefactory.cpp24
-rw-r--r--knode/knarticlefilter.cpp8
-rw-r--r--knode/knarticlemanager.cpp6
-rw-r--r--knode/kncleanup.cpp8
-rw-r--r--knode/kncollectionview.cpp2
-rw-r--r--knode/kncomposer.cpp56
-rw-r--r--knode/knconfig.cpp24
-rw-r--r--knode/knconfig.h2
-rw-r--r--knode/knconfigpages.cpp2
-rw-r--r--knode/knconfigwidgets.cpp36
-rw-r--r--knode/knconvert.cpp10
-rw-r--r--knode/kndisplayedheader.cpp4
-rw-r--r--knode/knfilterconfigwidget.cpp2
-rw-r--r--knode/knfilterdialog.cpp8
-rw-r--r--knode/knfolder.cpp6
-rw-r--r--knode/knfoldermanager.cpp4
-rw-r--r--knode/kngroup.cpp8
-rw-r--r--knode/kngroup.h8
-rw-r--r--knode/kngroupbrowser.cpp6
-rw-r--r--knode/kngroupdialog.cpp6
-rw-r--r--knode/kngroupmanager.cpp10
-rw-r--r--knode/kngroupmanager.h4
-rw-r--r--knode/kngrouppropdlg.cpp6
-rw-r--r--knode/kngroupselectdialog.cpp2
-rw-r--r--knode/knhdrviewitem.cpp8
-rw-r--r--knode/knhdrviewitem.h2
-rw-r--r--knode/knjobdata.cpp6
-rw-r--r--knode/knjobdata.h2
-rw-r--r--knode/knmainwidget.cpp42
-rw-r--r--knode/knmainwidget.h4
-rw-r--r--knode/knmemorymanager.cpp4
-rw-r--r--knode/knnetaccess.cpp38
-rw-r--r--knode/knnetaccess.h2
-rw-r--r--knode/knnntpaccount.cpp4
-rw-r--r--knode/knnntpclient.cpp18
-rw-r--r--knode/knode.cpp2
-rw-r--r--knode/knode_part.cpp2
-rw-r--r--knode/knprotocolclient.cpp6
-rw-r--r--knode/knrangefilter.cpp4
-rw-r--r--knode/knsearchdialog.cpp6
-rw-r--r--knode/knserverinfo.cpp2
-rw-r--r--knode/knstatusfilter.cpp2
-rw-r--r--knode/knstringfilter.cpp2
-rw-r--r--knode/knwidgets.cpp8
-rw-r--r--knode/knwidgets.h2
-rw-r--r--knode/smtpaccountwidget_base.ui2
-rw-r--r--knode/utilities.cpp6
52 files changed, 250 insertions, 250 deletions
diff --git a/knode/articlewidget.cpp b/knode/articlewidget.cpp
index 37f07d47..9e74cbb6 100644
--- a/knode/articlewidget.cpp
+++ b/knode/articlewidget.cpp
@@ -16,15 +16,15 @@
#include <sys/stat.h>
#include <tqbuffer.h>
-#include <clipboard.h>
+#include <tqclipboard.h>
#include <tqdir.h>
#include <tqfile.h>
#include <tqimage.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqpaintdevicemetrics.h>
#include <tqpopupmenu.h>
#include <tqstringlist.h>
-#include <textcodec.h>
+#include <tqtextcodec.h>
#include <tqtimer.h>
#include <kaction.h>
@@ -290,9 +290,9 @@ void ArticleWidget::readConfig()
mAttachmentStyle = conf->readEntry( "attachmentStyle", "inline" );
mHeaderStyle = conf->readEntry( "headerStyle", "fancy" );
KRadioAction *ra = 0;
- ra = static_cast<KRadioAction*>( mActionCollection->action( TQString("view_attachments_%1").arg(mAttachmentStyle).latin1() ) );
+ ra = static_cast<KRadioAction*>( mActionCollection->action( TQString("view_attachments_%1").tqarg(mAttachmentStyle).latin1() ) );
ra->setChecked( true );
- ra = static_cast<KRadioAction*>( mActionCollection->action( TQString("view_headers_%1").arg(mHeaderStyle).latin1() ) );
+ ra = static_cast<KRadioAction*>( mActionCollection->action( TQString("view_headers_%1").tqarg(mHeaderStyle).latin1() ) );
ra->setChecked( true );
delete mCSSHelper;
@@ -402,7 +402,7 @@ void ArticleWidget::displayArticle()
// check if codec is available
if ( text && !canDecodeText( text->contentType()->charset() ) ) {
html += TQString("<table width=\"100%\" border=\"0\"><tr><td bgcolor=\"#FF0000\">%1</td></tr></table>")
- .arg( i18n("Unknown charset. Default charset is used instead.") );
+ .tqarg( i18n("Unknown charset. Default charset is used instead.") );
kdDebug(5003) << k_funcinfo << "unknown charset = " << text->contentType()->charset() << endl;
}
@@ -560,8 +560,8 @@ void ArticleWidget::displayHeader()
if ( header ) {
headerHtml += "<tr>";
headerHtml+=TQString( "<td align=\"right\" valign=\"top\"><b>%1</b></td><td width=\"100%\">%2</td></tr>" )
- .arg( toHtmlString( header->type(), None ) + ": " )
- .arg( toHtmlString( header->asUnicodeString() , ParseURL ) );
+ .tqarg( toHtmlString( header->type(), None ) + ": " )
+ .tqarg( toHtmlString( header->asUnicodeString() , ParseURL ) );
delete header;
}
}
@@ -597,8 +597,8 @@ void ArticleWidget::displayHeader()
if ( hb->is("From") ) {
headerHtml += TQString( "<a href=\"mailto:%1\">%2</a>")
- .arg( KPIM::getEmailAddress( hb->asUnicodeString() ) )
- .arg( toHtmlString( hb->asUnicodeString(), None ) );
+ .tqarg( KPIM::getEmailAddress( hb->asUnicodeString() ) )
+ .tqarg( toHtmlString( hb->asUnicodeString(), None ) );
KMime::Headers::Base *orgHdr = mArticle->getHeaderByType( "Organization" );
if ( orgHdr && !orgHdr->isEmpty() ) {
headerHtml += "&nbsp;&nbsp;(";
@@ -635,8 +635,8 @@ void ArticleWidget::displayHeader()
TQString xface = "";
if ( !xfhead.isEmpty() ) {
KPIM::KXFace xf;
- xface = TQString::fromLatin1( "<div class=\"senderpic\"><img src=\"%1\" width=\"48\" height=\"48\"/></div>" )
- .arg( imgToDataUrl( xf.toImage( xfhead ), "PNG" ) );
+ xface = TQString::tqfromLatin1( "<div class=\"senderpic\"><img src=\"%1\" width=\"48\" height=\"48\"/></div>" )
+ .tqarg( imgToDataUrl( xf.toImage( xfhead ), "PNG" ) );
}
// fancy header style
@@ -660,10 +660,10 @@ void ArticleWidget::displayHeader()
int refCnt = refs->count(), i = 1;
TQCString id = refs->first();
id = id.mid( 1, id.length() - 2 ); // remove <>
- html += TQString( "<b>%1</b>" ).arg( i18n("References:") );
+ html += TQString( "<b>%1</b>" ).tqarg( i18n("References:") );
while ( i <= refCnt ) {
- html += " <a href=\"news:" + TQString::fromLatin1( id ) + "\">" + TQString::number( i ) + "</a>";
+ html += " <a href=\"news:" + TQString::tqfromLatin1( id ) + "\">" + TQString::number( i ) + "</a>";
id = refs->next();
id = id.mid( 1, id.length() - 2 ); // remove <>
i++;
@@ -748,7 +748,7 @@ TQString ArticleWidget::displaySigHeader( Kpgp::Block* block )
TQString message;
if ( signer.isEmpty() ) {
message = i18n( "Message was signed with unknown key 0x%1." )
- .arg( TQString(signerKey) );
+ .tqarg( TQString(signerKey) );
message += "<br/>";
message += i18n( "The validity of the signature cannot be verified." );
signClass = "signWarn";
@@ -769,10 +769,10 @@ TQString ArticleWidget::displaySigHeader( Kpgp::Block* block )
if( !signerKey.isEmpty() )
message += i18n( "Message was signed by %1 (Key ID: 0x%2)." )
- .arg( signer )
- .arg( TQString(signerKey) );
+ .tqarg( signer )
+ .tqarg( TQString(signerKey) );
else
- message += i18n( "Message was signed by %1." ).arg( signer );
+ message += i18n( "Message was signed by %1." ).tqarg( signer );
message += "<br/>";
if( block->goodSignature() ) {
@@ -915,8 +915,8 @@ TQString ArticleWidget::imgToDataUrl( const TQImage &image, const char* fmt )
TQBuffer buffer( ba );
buffer.open( IO_WriteOnly );
image.save( &buffer, fmt );
- return TQString::fromLatin1("data:image/%1;base64,%2")
- .arg( fmt, TQString(KCodecs::base64Encode( ba )) );
+ return TQString::tqfromLatin1("data:image/%1;base64,%2")
+ .tqarg( fmt, TQString(KCodecs::base64Encode( ba )) );
}
@@ -1030,7 +1030,7 @@ void ArticleWidget::processJob( KNJobData * job )
if ( !job->canceled() ) {
if ( !job->success() )
KMessageBox::error( this, i18n("An error occurred while downloading the article source:\n")
- .arg( job->errorString() ) );
+ .tqarg( job->errorString() ) );
else
new KNSourceViewWindow( a->head() + "\n" + a->body() );
}
@@ -1408,15 +1408,15 @@ void ArticleWidget::slotCopyURL()
address = mCurrentURL.path();
else
address = mCurrentURL.url();
- TQApplication::clipboard()->setText( address, TQClipboard::Clipboard );
- TQApplication::clipboard()->setText( address, TQClipboard::Selection );
+ TQApplication::tqclipboard()->setText( address, TQClipboard::Clipboard );
+ TQApplication::tqclipboard()->setText( address, TQClipboard::Selection );
}
void ArticleWidget::slotAddBookmark()
{
if ( mCurrentURL.isEmpty() )
return;
- TQString filename = locateLocal( "data", TQString::fromLatin1("konqueror/bookmarks.xml") );
+ TQString filename = locateLocal( "data", TQString::tqfromLatin1("konqueror/bookmarks.xml") );
KBookmarkManager *bookManager = KBookmarkManager::managerForFile( filename, false );
KBookmarkGroup group = bookManager->root();
group.addBookmark( bookManager, mCurrentURL.url(), mCurrentURL );
diff --git a/knode/knaccountmanager.cpp b/knode/knaccountmanager.cpp
index 2dc8c931..627ff4cd 100644
--- a/knode/knaccountmanager.cpp
+++ b/knode/knaccountmanager.cpp
@@ -127,12 +127,12 @@ bool KNAccountManager::newAccount(KNNntpAccount *a)
TQStringList entries(d.entryList("nntp.*", TQDir::Dirs));
int id = 1;
- while (entries.findIndex(TQString("nntp.%1").arg(id))!=-1)
+ while (entries.findIndex(TQString("nntp.%1").tqarg(id))!=-1)
++id;
a->setId(id);
- dir = locateLocal("data",TQString("knode/nntp.%1/").arg(a->id()));
+ dir = locateLocal("data",TQString("knode/nntp.%1/").tqarg(a->id()));
if (!dir.isNull()) {
mAccounts.append(a);
emit(accountAdded(a));
@@ -177,7 +177,7 @@ bool KNAccountManager::removeAccount(KNNntpAccount *a)
}
}
dir.cdUp(); // directory should now be empty, deleting it
- dir.rmdir(TQString("nntp.%1/").arg(a->id()));
+ dir.rmdir(TQString("nntp.%1/").tqarg(a->id()));
}
if(c_urrentAccount==a) setCurrentAccount(0);
@@ -223,7 +223,7 @@ void KNAccountManager::loadPasswordsAsync()
if ( !mWallet && !mWalletOpenFailed ) {
if ( knGlobals.top )
mWallet = Wallet::openWallet( Wallet::NetworkWallet(),
- knGlobals.topWidget->topLevelWidget()->winId(),
+ knGlobals.topWidget->tqtopLevelWidget()->winId(),
Wallet::Asynchronous );
else
mWallet = Wallet::openWallet( Wallet::NetworkWallet(), 0, Wallet::Asynchronous );
@@ -263,7 +263,7 @@ KWallet::Wallet* KNAccountManager::wallet()
delete mWallet;
if ( knGlobals.top )
mWallet = Wallet::openWallet( Wallet::NetworkWallet(),
- knGlobals.topWidget->topLevelWidget()->winId() );
+ knGlobals.topWidget->tqtopLevelWidget()->winId() );
else
mWallet = Wallet::openWallet( Wallet::NetworkWallet() );
diff --git a/knode/knarticle.cpp b/knode/knarticle.cpp
index fe475b1b..e253d2ef 100644
--- a/knode/knarticle.cpp
+++ b/knode/knarticle.cpp
@@ -209,7 +209,7 @@ void KNRemoteArticle::updateListItem()
i_tem->setExpandable( (threadMode() && hasVisibleFollowUps()) );
- i_tem->repaint(); //force repaint
+ i_tem->tqrepaint(); //force tqrepaint
}
diff --git a/knode/knarticle.h b/knode/knarticle.h
index b4e039ff..798742e1 100644
--- a/knode/knarticle.h
+++ b/knode/knarticle.h
@@ -16,7 +16,7 @@
#define KNARTICLE_H
#include <tqstringlist.h>
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqfile.h>
#include <tqfont.h>
#include <tqcolor.h>
diff --git a/knode/knarticlefactory.cpp b/knode/knarticlefactory.cpp
index 2b686cf2..d82bb5c7 100644
--- a/knode/knarticlefactory.cpp
+++ b/knode/knarticlefactory.cpp
@@ -12,7 +12,7 @@
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
*/
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqvbox.h>
@@ -209,9 +209,9 @@ void KNArticleFactory::createReply(KNRemoteArticle *a, TQString selectedText, bo
TQString attribution=knGlobals.configManager()->postNewsComposer()->intro();
TQString name(a->from()->name());
if (name.isEmpty())
- name = TQString::fromLatin1(a->from()->email());
+ name = TQString::tqfromLatin1(a->from()->email());
attribution.replace(TQRegExp("%NAME"),name);
- attribution.replace(TQRegExp("%EMAIL"),TQString::fromLatin1(a->from()->email()));
+ attribution.replace(TQRegExp("%EMAIL"),TQString::tqfromLatin1(a->from()->email()));
attribution.replace(TQRegExp("%DATE"),KGlobal::locale()->formatDateTime(a->date()->qdt(),false));
attribution.replace(TQRegExp("%MSID"),a->messageID()->asUnicodeString());
attribution.replace(TQRegExp("%GROUP"),g->groupname());
@@ -306,7 +306,7 @@ void KNArticleFactory::createForward(KNArticle *a)
//--------------------------- <Body> -----------------------------
- TQString fwd = TQString("\n--------------- %1\n\n").arg(i18n("Forwarded message (begin)"));
+ TQString fwd = TQString("\n--------------- %1\n\n").tqarg(i18n("Forwarded message (begin)"));
fwd+=( i18n("Subject") + ": " + a->subject()->asUnicodeString() + "\n" );
fwd+=( i18n("From") + ": " + a->from()->asUnicodeString() + "\n" );
@@ -321,7 +321,7 @@ void KNArticleFactory::createForward(KNArticle *a)
fwd += (*it) + "\n";
}
- fwd += TQString("\n--------------- %1\n").arg(i18n("Forwarded message (end)"));
+ fwd += TQString("\n--------------- %1\n").tqarg(i18n("Forwarded message (end)"));
//--------------------------- </Body> ----------------------------
@@ -419,7 +419,7 @@ void KNArticleFactory::createCancel(KNArticle *a)
art->lines()->setNumberOfLines(1);
//body
- art->fromUnicodeString(TQString::fromLatin1("cancel by original author\n"));
+ art->fromUnicodeString(TQString::tqfromLatin1("cancel by original author\n"));
//assemble
art->assemble();
@@ -601,7 +601,7 @@ void KNArticleFactory::edit(KNLocalArticle *a)
KMessageBox::information(knGlobals.topWidget,
i18n("<qt>The signature generator program produced the "
"following output:<br><br>%1</qt>")
- .arg(id->getSigGeneratorStdErr()));
+ .tqarg(id->getSigGeneratorStdErr()));
mCompList.append( com );
connect(com, TQT_SIGNAL(composerDone(KNComposer*)), this, TQT_SLOT(slotComposerDone(KNComposer*)));
@@ -875,9 +875,9 @@ KNLocalArticle* KNArticleFactory::newArticle(KNCollection *col, TQString &sig, T
if(origPost) {
TQString name(origPost->from()->name());
if (name.isEmpty())
- name = TQString::fromLatin1(origPost->from()->email());
+ name = TQString::tqfromLatin1(origPost->from()->email());
value.replace(TQRegExp("%NAME"), name);
- value.replace(TQRegExp("%EMAIL"), TQString::fromLatin1(origPost->from()->email()));
+ value.replace(TQRegExp("%EMAIL"), TQString::tqfromLatin1(origPost->from()->email()));
}
else
if(value.find("%NAME") != -1 || value.find("%EMAIL") != -1)
@@ -895,7 +895,7 @@ KNLocalArticle* KNArticleFactory::newArticle(KNCollection *col, TQString &sig, T
KMessageBox::information(knGlobals.topWidget,
i18n("<qt>The signature generator program produced the "
"following output:<br><br>%1</qt>")
- .arg(id->getSigGeneratorStdErr()));
+ .tqarg(id->getSigGeneratorStdErr()));
}
else
sig=TQString();
@@ -1070,8 +1070,8 @@ KNSendErrorDialog::KNSendErrorDialog()
TQVBox *page = makeVBoxMainWidget();
- new TQLabel(TQString("<b>%1</b><br>%2").arg(i18n("Errors occurred while sending these articles:"))
- .arg(i18n("The unsent articles are stored in the \"Outbox\" folder.")), page);
+ new TQLabel(TQString("<b>%1</b><br>%2").tqarg(i18n("Errors occurred while sending these articles:"))
+ .tqarg(i18n("The unsent articles are stored in the \"Outbox\" folder.")), page);
j_obs=new KNDialogListBox(true, page);
e_rror=new TQLabel(TQString(), page);
diff --git a/knode/knarticlefilter.cpp b/knode/knarticlefilter.cpp
index 65acb7c0..35998519 100644
--- a/knode/knarticlefilter.cpp
+++ b/knode/knarticlefilter.cpp
@@ -74,7 +74,7 @@ KNArticleFilter::~KNArticleFilter()
bool KNArticleFilter::loadInfo()
{
if (i_d!=-1) {
- TQString fname(locate("data",TQString( "knode/filters/%1.fltr" ).arg(i_d) ) );
+ TQString fname(locate("data",TQString( "knode/filters/%1.fltr" ).tqarg(i_d) ) );
if (fname.isNull())
return false;
@@ -94,7 +94,7 @@ bool KNArticleFilter::loadInfo()
void KNArticleFilter::load()
{
- TQString fname(locate("data",TQString( "knode/filters/%1.fltr").arg(i_d) ) );
+ TQString fname(locate("data",TQString( "knode/filters/%1.fltr").tqarg(i_d) ) );
if (fname.isNull())
return;
@@ -141,7 +141,7 @@ void KNArticleFilter::save()
KNHelper::displayInternalFileError();
return;
}
- KSimpleConfig conf(dir+TQString("%1.fltr").arg(i_d));
+ KSimpleConfig conf(dir+TQString("%1.fltr").tqarg(i_d));
conf.setGroup("GENERAL");
conf.writeEntry("name", TQString(n_ame));
@@ -324,7 +324,7 @@ void KNArticleFilter::setTranslatedName(const TQString &s)
bool retranslated = false;
for (const char **c=defFil;(*c)!=0;c++) // ok, try if it matches any of the standard filter names
if (s==i18n("default filter name",*c)) {
- n_ame = TQString::fromLatin1(*c);
+ n_ame = TQString::tqfromLatin1(*c);
retranslated = true;
break;
}
diff --git a/knode/knarticlemanager.cpp b/knode/knarticlemanager.cpp
index 088e9881..7673eabf 100644
--- a/knode/knarticlemanager.cpp
+++ b/knode/knarticlemanager.cpp
@@ -992,10 +992,10 @@ void KNArticleManager::updateStatusString()
name += i18n(" (moderated)");
knGlobals.seStatusMsg(i18n(" %1: %2 new , %3 displayed")
- .arg(name).arg(g_roup->newCount()).arg(displCnt),SB_GROUP);
+ .tqarg(name).tqarg(g_roup->newCount()).tqarg(displCnt),SB_GROUP);
if(f_ilter)
- knGlobals.seStatusMsg(i18n(" Filter: %1").arg(f_ilter->translatedName()), SB_FILTER);
+ knGlobals.seStatusMsg(i18n(" Filter: %1").tqarg(f_ilter->translatedName()), SB_FILTER);
else
knGlobals.seStatusMsg(TQString(), SB_FILTER);
}
@@ -1005,7 +1005,7 @@ void KNArticleManager::updateStatusString()
else
displCnt=f_older->count();
knGlobals.seStatusMsg(i18n(" %1: %2 displayed")
- .arg(f_older->name()).arg(displCnt), SB_GROUP);
+ .tqarg(f_older->name()).tqarg(displCnt), SB_GROUP);
knGlobals.seStatusMsg(TQString(), SB_FILTER);
} else {
knGlobals.seStatusMsg(TQString(), SB_GROUP);
diff --git a/knode/kncleanup.cpp b/knode/kncleanup.cpp
index 70ab15f4..28993e7c 100644
--- a/knode/kncleanup.cpp
+++ b/knode/kncleanup.cpp
@@ -16,7 +16,7 @@
#include <tqdir.h>
#include <tqlabel.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqprogressbar.h>
#include <klocale.h>
@@ -56,13 +56,13 @@ void KNCleanUp::start()
for ( TQValueList<KNArticleCollection*>::Iterator it = mColList.begin(); it != mColList.end(); ++it ) {
if ( (*it)->type() == KNCollection::CTgroup ) {
- d_lg->showMessage( i18n("Deleting expired articles in <b>%1</b>").arg( (*it)->name() ) );
+ d_lg->showMessage( i18n("Deleting expired articles in <b>%1</b>").tqarg( (*it)->name() ) );
kapp->processEvents();
expireGroup( static_cast<KNGroup*>( (*it) ) );
d_lg->doProgress();
}
else if ( (*it)->type() == KNCollection::CTfolder ) {
- d_lg->showMessage( i18n("Compacting folder <b>%1</b>").arg( (*it)->name() ) );
+ d_lg->showMessage( i18n("Compacting folder <b>%1</b>").tqarg( (*it)->name() ) );
kapp->processEvents();
compactFolder( static_cast<KNFolder*>( (*it) ) );
d_lg->doProgress();
@@ -187,7 +187,7 @@ void KNCleanUp::expireGroup( KNGroup *g, bool showResult )
if(showResult)
KMessageBox::information(knGlobals.topWidget,
- i18n("<b>%1</b><br>expired: %2<br>left: %3").arg(g->groupname()).arg(delCnt).arg(leftCnt));
+ i18n("<b>%1</b><br>expired: %2<br>left: %3").tqarg(g->groupname()).tqarg(delCnt).tqarg(leftCnt));
}
diff --git a/knode/kncollectionview.cpp b/knode/kncollectionview.cpp
index e1fb2069..7b73cc7b 100644
--- a/knode/kncollectionview.cpp
+++ b/knode/kncollectionview.cpp
@@ -93,7 +93,7 @@ void KNCollectionView::readConfig()
KConfig *conf = knGlobals.config();
conf->setGroup( "GroupView" );
- // execute the listview layout stuff only once
+ // execute the listview tqlayout stuff only once
static bool initDone = false;
if (!initDone) {
initDone = true;
diff --git a/knode/kncomposer.cpp b/knode/kncomposer.cpp
index ac14f060..de354ef7 100644
--- a/knode/kncomposer.cpp
+++ b/knode/kncomposer.cpp
@@ -13,8 +13,8 @@
*/
#include <tqheader.h>
-#include <textcodec.h>
-#include <clipboard.h>
+#include <tqtextcodec.h>
+#include <tqclipboard.h>
#include <tqapplication.h>
#include <kspelldlg.h>
#include <tdeversion.h>
@@ -432,7 +432,7 @@ int KNComposer::listOfResultOfCheckWord( const TQStringList & lst , const TQStri
void KNComposer::slotUndo()
{
- TQWidget* fw = focusWidget();
+ TQWidget* fw = tqfocusWidget();
if (!fw) return;
if (fw->inherits("KEdit"))
@@ -443,7 +443,7 @@ void KNComposer::slotUndo()
void KNComposer::slotRedo()
{
- TQWidget* fw = focusWidget();
+ TQWidget* fw = tqfocusWidget();
if (!fw) return;
if (fw->inherits("KEdit"))
@@ -454,7 +454,7 @@ void KNComposer::slotRedo()
void KNComposer::slotCut()
{
- TQWidget* fw = focusWidget();
+ TQWidget* fw = tqfocusWidget();
if (!fw) return;
if (fw->inherits("KEdit"))
@@ -466,7 +466,7 @@ void KNComposer::slotCut()
void KNComposer::slotCopy()
{
- TQWidget* fw = focusWidget();
+ TQWidget* fw = tqfocusWidget();
if (!fw) return;
if (fw->inherits("KEdit"))
@@ -480,7 +480,7 @@ void KNComposer::slotCopy()
void KNComposer::slotPaste()
{
- TQWidget* fw = focusWidget();
+ TQWidget* fw = tqfocusWidget();
if (!fw) return;
if (fw->inherits("KEdit"))
@@ -492,7 +492,7 @@ void KNComposer::slotPaste()
void KNComposer::slotSelectAll()
{
- TQWidget* fw = focusWidget();
+ TQWidget* fw = tqfocusWidget();
if (!fw) return;
if (fw->inherits(TQLINEEDIT_OBJECT_NAME_STRING))
@@ -969,7 +969,7 @@ void KNComposer::insertFile(TQFile *file, bool clear, bool box, TQString boxTitl
ts.setCodec(codec);
if (box)
- temp = TQString::fromLatin1(",----[ %1 ]\n").arg(boxTitle);
+ temp = TQString::tqfromLatin1(",----[ %1 ]\n").tqarg(boxTitle);
if (box && (v_iew->e_dit->wordWrap()!=TQMultiLineEdit::NoWrap)) {
int wrapAt = v_iew->e_dit->wrapColumnOrWidth();
@@ -993,7 +993,7 @@ void KNComposer::insertFile(TQFile *file, bool clear, bool box, TQString boxTitl
}
if (box)
- temp += TQString::fromLatin1("`----");
+ temp += TQString::tqfromLatin1("`----");
if(clear)
v_iew->e_dit->setText(temp);
@@ -1374,18 +1374,18 @@ void KNComposer::slotUpdateStatusBar()
else
overwriteDesc = i18n(" INS ");
- statusBar()->changeItem(i18n(" Type: %1 ").arg(typeDesc), 1);
- statusBar()->changeItem(i18n(" Charset: %1 ").arg(TQString(c_harset)), 2);
+ statusBar()->changeItem(i18n(" Type: %1 ").tqarg(typeDesc), 1);
+ statusBar()->changeItem(i18n(" Charset: %1 ").tqarg(TQString(c_harset)), 2);
statusBar()->changeItem(overwriteDesc, 3);
- statusBar()->changeItem(i18n(" Column: %1 ").arg(v_iew->e_dit->currentColumn() + 1), 4);
- statusBar()->changeItem(i18n(" Line: %1 ").arg(v_iew->e_dit->currentLine() + 1), 5);
+ statusBar()->changeItem(i18n(" Column: %1 ").tqarg(v_iew->e_dit->currentColumn() + 1), 4);
+ statusBar()->changeItem(i18n(" Line: %1 ").tqarg(v_iew->e_dit->currentLine() + 1), 5);
}
void KNComposer::slotUpdateCursorPos()
{
- statusBar()->changeItem(i18n(" Column: %1 ").arg(v_iew->e_dit->currentColumn() + 1), 4);
- statusBar()->changeItem(i18n(" Line: %1 ").arg(v_iew->e_dit->currentLine() + 1), 5);
+ statusBar()->changeItem(i18n(" Column: %1 ").tqarg(v_iew->e_dit->currentColumn() + 1), 4);
+ statusBar()->changeItem(i18n(" Line: %1 ").tqarg(v_iew->e_dit->currentLine() + 1), 5);
}
@@ -1447,7 +1447,7 @@ void KNComposer::slotGroupsChanged(const TQString &t)
split.init(t.latin1(), ",");
splitOk=split.first();
while(splitOk) {
- v_iew->f_up2->insertItem(TQString::fromLatin1(split.string()));
+ v_iew->f_up2->insertItem(TQString::tqfromLatin1(split.string()));
splitOk=split.next();
}
v_iew->f_up2->insertItem("");
@@ -1781,10 +1781,10 @@ KNComposer::ComposerView::ComposerView(KNComposer *composer, const char *n)
KConfig *config = knGlobals.config();
KConfigGroupSaver saver(config, "VISUAL_APPEARANCE");
- TQColor defaultColor1( kapp->palette().active().text()); // defaults from kmreaderwin.cpp
- TQColor defaultColor2( kapp->palette().active().text() );
- TQColor defaultColor3( kapp->palette().active().text() );
- TQColor defaultForeground( kapp->palette().active().text() );
+ TQColor defaultColor1( kapp->tqpalette().active().text()); // defaults from kmreaderwin.cpp
+ TQColor defaultColor2( kapp->tqpalette().active().text() );
+ TQColor defaultColor3( kapp->tqpalette().active().text() );
+ TQColor defaultForeground( kapp->tqpalette().active().text() );
TQColor col1 = config->readColorEntry( "ForegroundColor", &defaultForeground );
TQColor col2 = config->readColorEntry( "quote3Color", &defaultColor3 );
TQColor col3 = config->readColorEntry( "quote2Color", &defaultColor2 );
@@ -1998,7 +1998,7 @@ KNComposer::Editor::Editor(KNComposer::ComposerView *_composerView, KNComposer *
spell = 0L;
installEventFilter(this);
KCursor::setAutoHideCursor( this, true, true );
- m_bound = TQRegExp( TQString::fromLatin1("[\\s\\W]") );
+ m_bound = TQRegExp( TQString::tqfromLatin1("[\\s\\W]") );
}
@@ -2152,7 +2152,7 @@ TQStringList KNComposer::Editor::processedText()
void KNComposer::Editor::slotPasteAsQuotation()
{
- TQString s = TQApplication::clipboard()->text();
+ TQString s = TQApplication::tqclipboard()->text();
if (!s.isEmpty()) {
for (int i=0; (uint)i<s.length(); i++) {
if ( s[i] < ' ' && s[i] != '\n' && s[i] != '\t' )
@@ -2233,7 +2233,7 @@ void KNComposer::Editor::slotAddBox()
} else {
int l = currentLine();
int c = currentColumn();
- TQString s = TQString::fromLatin1(",----[ ]\n| %1\n`----").arg(textLine(l));
+ TQString s = TQString::tqfromLatin1(",----[ ]\n| %1\n`----").tqarg(textLine(l));
insertLine(s,l);
removeLine(l+3);
setCursorPosition(l+1,c+2);
@@ -2244,7 +2244,7 @@ void KNComposer::Editor::slotAddBox()
void KNComposer::Editor::slotRemoveBox()
{
if (hasMarkedText()) {
- TQString s = TQString::fromLatin1("\n") + markedText() + TQString::fromLatin1("\n");
+ TQString s = TQString::tqfromLatin1("\n") + markedText() + TQString::tqfromLatin1("\n");
s.replace(TQRegExp("\n,----[^\n]*\n"),"\n");
s.replace(TQRegExp("\n| "),"\n");
s.replace(TQRegExp("\n`----[^\n]*\n"),"\n");
@@ -2297,7 +2297,7 @@ void KNComposer::Editor::slotRemoveBox()
setCursorPosition(l,c-2);
setAutoUpdate(true);
- repaint(false);
+ tqrepaint(false);
}
}
@@ -2560,7 +2560,7 @@ KNComposer::AttachmentPropertiesDlg::AttachmentPropertiesDlg(KNAttachment *a, TQ
fileL->addRowSpacing(0, fontMetrics().lineSpacing()-9);
fileL->addWidget(new TQLabel(i18n("Name:"), fileGB) ,1,0);
- fileL->addWidget(new TQLabel(TQString("<b>%1</b>").arg(a->name()), fileGB), 1,1, TQt::AlignLeft);
+ fileL->addWidget(new TQLabel(TQString("<b>%1</b>").tqarg(a->name()), fileGB), 1,1, TQt::AlignLeft);
fileL->addWidget(new TQLabel(i18n("Size:"), fileGB), 2,0);
fileL->addWidget(new TQLabel(a->contentSize(), fileGB), 2,1, TQt::AlignLeft);
@@ -2604,7 +2604,7 @@ KNComposer::AttachmentPropertiesDlg::AttachmentPropertiesDlg(KNAttachment *a, TQ
this, TQT_SLOT(slotMimeTypeTextChanged(const TQString&)));
//finish GUI
- setFixedHeight(sizeHint().height());
+ setFixedHeight(tqsizeHint().height());
KNHelper::restoreWindowSize("attProperties", this, TQSize(300,250));
setHelp("anc-knode-editor-advanced");
}
diff --git a/knode/knconfig.cpp b/knode/knconfig.cpp
index 4e2d7f33..98caed2b 100644
--- a/knode/knconfig.cpp
+++ b/knode/knconfig.cpp
@@ -16,7 +16,7 @@
#include <stdlib.h>
-#include <textcodec.h>
+#include <tqtextcodec.h>
#include <ksimpleconfig.h>
#include <kmessagebox.h>
@@ -452,7 +452,7 @@ TQColor KNConfig::Appearance::defaultColor(int i) const
switch(i) {
case background:
- return kapp->palette().active().base();
+ return kapp->tqpalette().active().base();
case alternateBackground:
return KGlobalSettings::alternateBackgroundColor();
@@ -466,13 +466,13 @@ TQColor KNConfig::Appearance::defaultColor(int i) const
case normalText:
case unreadThread:
- return kapp->palette().active().text();
+ return kapp->tqpalette().active().text();
case url:
return KGlobalSettings::linkColor();
case readThread:
- return kapp->palette().disabled().text();
+ return kapp->tqpalette().disabled().text();
case unreadArticle:
return TQColor( 183, 154, 11 );
@@ -492,7 +492,7 @@ TQColor KNConfig::Appearance::defaultColor(int i) const
return TQColor( 0xFF, 0x40, 0x40 );
}
- return kapp->palette().disabled().text();
+ return kapp->tqpalette().disabled().text();
}
@@ -942,11 +942,11 @@ void KNConfig::PostNewsTechnical::save()
conf->setGroup("POSTNEWS");
conf->writeEntry("ComposerCharsets", c_omposerCharsets);
- conf->writeEntry("Charset", TQString::fromLatin1(c_harset));
+ conf->writeEntry("Charset", TQString::tqfromLatin1(c_harset));
conf->writeEntry("8BitEncoding", a_llow8BitBody);
conf->writeEntry("UseOwnCharset", u_seOwnCharset);
conf->writeEntry("generateMId", g_enerateMID);
- conf->writeEntry("MIdhost", TQString::fromLatin1(h_ostname));
+ conf->writeEntry("MIdhost", TQString::tqfromLatin1(h_ostname));
conf->writeEntry("dontIncludeUA", d_ontIncludeUA);
conf->writeEntry("useExternalMailer", u_seExternalMailer);
@@ -1100,7 +1100,7 @@ KNConfig::Cleanup::Cleanup( bool global ) :
// default values for new accounts / groups
d_oExpire( true ), r_emoveUnavailable( true ), p_reserveThr( true ),
e_xpireInterval( 5 ), r_eadMaxAge( 10 ), u_nreadMaxAge( 15 ),
- mGlobal(global), mDefault(!global), mLastExpDate( TQDate::currentDate() )
+ mGlobal(global), mDefault(!global), mLastExpDate( TQDate::tqcurrentDate() )
{
if (mGlobal) {
KConfig *conf = knGlobals.config();
@@ -1174,7 +1174,7 @@ bool KNConfig::Cleanup::expireToday()
if (!d_oExpire)
return false;
- TQDate today = TQDate::currentDate();
+ TQDate today = TQDate::tqcurrentDate();
if (mLastExpDate == TQDateTime(today))
return false;
@@ -1184,7 +1184,7 @@ bool KNConfig::Cleanup::expireToday()
void KNConfig::Cleanup::setLastExpireDate()
{
- mLastExpDate = TQDateTime::currentDateTime();
+ mLastExpDate = TQDateTime::tqcurrentDateTime();
}
@@ -1193,7 +1193,7 @@ bool KNConfig::Cleanup::compactToday()
if (!d_oCompact)
return false;
- TQDate today = TQDate::currentDate();
+ TQDate today = TQDate::tqcurrentDate();
if (mLastCompDate == TQDateTime(today))
return false;
@@ -1203,7 +1203,7 @@ bool KNConfig::Cleanup::compactToday()
void KNConfig::Cleanup::setLastCompactDate()
{
- mLastCompDate = TQDateTime::currentDateTime();
+ mLastCompDate = TQDateTime::tqcurrentDateTime();
}
diff --git a/knode/knconfig.h b/knode/knconfig.h
index 0f0f868c..f2fd7d11 100644
--- a/knode/knconfig.h
+++ b/knode/knconfig.h
@@ -391,7 +391,7 @@ class KDE_EXPORT XHeader {
TQCString name() { return n_ame; }
TQString value() { return v_alue; }
- TQString header() { return (TQString::fromLatin1(("X-"+n_ame+": "))+v_alue); }
+ TQString header() { return (TQString::tqfromLatin1(("X-"+n_ame+": "))+v_alue); }
protected:
TQCString n_ame;
diff --git a/knode/knconfigpages.cpp b/knode/knconfigpages.cpp
index 547bf27a..c44b9695 100644
--- a/knode/knconfigpages.cpp
+++ b/knode/knconfigpages.cpp
@@ -11,7 +11,7 @@
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
*/
-#include <layout.h>
+#include <tqlayout.h>
#include <kcmodule.h>
#include <kdebug.h>
diff --git a/knode/knconfigwidgets.cpp b/knode/knconfigwidgets.cpp
index b34d7638..0860ee05 100644
--- a/knode/knconfigwidgets.cpp
+++ b/knode/knconfigwidgets.cpp
@@ -395,8 +395,8 @@ void KNConfig::NntpAccountListWidget::slotSelectionChanged()
LBoxItem *it = static_cast<LBoxItem*>(l_box->item(curr));
if(it) {
- s_erverInfo->setText(i18n("Server: %1").arg(it->account->server()));
- p_ortInfo->setText(i18n("Port: %1").arg(it->account->port()));
+ s_erverInfo->setText(i18n("Server: %1").tqarg(it->account->server()));
+ p_ortInfo->setText(i18n("Port: %1").tqarg(it->account->port()));
}
else {
s_erverInfo->setText(i18n("Server: "));
@@ -461,7 +461,7 @@ void KNConfig::NntpAccountListWidget::slotSubBtnClicked()
KNConfig::NntpAccountConfDialog::NntpAccountConfDialog(KNNntpAccount *a, TQWidget *p, const char *n)
- : KDialogBase(Tabbed, (a->id()!=-1)? i18n("Properties of %1").arg(a->name()):i18n("New Account"),
+ : KDialogBase(Tabbed, (a->id()!=-1)? i18n("Properties of %1").tqarg(a->name()):i18n("New Account"),
Ok|Cancel|Help, Ok, p, n),
a_ccount(a)
{
@@ -561,7 +561,7 @@ KNConfig::NntpAccountConfDialog::NntpAccountConfDialog(KNNntpAccount *a, TQWidge
connect( knGlobals.accountManager(), TQT_SIGNAL(passwordsChanged()), TQT_SLOT(slotPasswordChanged()) );
- KNHelper::restoreWindowSize("accNewsPropDLG", this, sizeHint());
+ KNHelper::restoreWindowSize("accNewsPropDLG", this, tqsizeHint());
setHelp("anc-setting-the-news-account");
}
@@ -773,7 +773,7 @@ int KNConfig::AppearanceWidget::ColorListItem::width(const TQListBox *lb ) const
KNConfig::AppearanceWidget::FontListItem::FontListItem( const TQString &name, const TQFont &font )
: TQListBoxText(name), f_ont(font)
{
- fontInfo = TQString("[%1 %2]").arg(f_ont.family()).arg(f_ont.pointSize());
+ fontInfo = TQString("[%1 %2]").tqarg(f_ont.family()).tqarg(f_ont.pointSize());
}
@@ -785,7 +785,7 @@ KNConfig::AppearanceWidget::FontListItem::~FontListItem()
void KNConfig::AppearanceWidget::FontListItem::setFont(const TQFont &font)
{
f_ont = font;
- fontInfo = TQString("[%1 %2]").arg(f_ont.family()).arg(f_ont.pointSize());
+ fontInfo = TQString("[%1 %2]").tqarg(f_ont.family()).tqarg(f_ont.pointSize());
}
@@ -896,7 +896,7 @@ void KNConfig::AppearanceWidget::defaults()
colorItem->setColor(d_ata->defaultColor(i));
}
c_List->triggerUpdate(true);
- c_List->repaint(true);
+ c_List->tqrepaint(true);
// default fonts
FontListItem *fontItem;
@@ -1548,8 +1548,8 @@ KNConfig::DisplayedHeaderConfDialog::DisplayedHeaderConfDialog(KNDisplayedHeader
v_alueCB[i]->setChecked(h->flag(i+4));
}
- setFixedHeight(sizeHint().height());
- KNHelper::restoreWindowSize("accReadHdrPropDLG", this, sizeHint());
+ setFixedHeight(tqsizeHint().height());
+ KNHelper::restoreWindowSize("accReadHdrPropDLG", this, tqsizeHint());
connect(n_ameE, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotNameChanged(const TQString&)));
@@ -2138,8 +2138,8 @@ KNConfig::XHeaderConfDialog::XHeaderConfDialog(const TQString &h, TQWidget *p, c
v_alue->setText(h.mid(pos, h.length()-pos));
}
- setFixedHeight(sizeHint().height());
- KNHelper::restoreWindowSize("XHeaderDlg", this, sizeHint());
+ setFixedHeight(tqsizeHint().height());
+ KNHelper::restoreWindowSize("XHeaderDlg", this, tqsizeHint());
n_ame->setFocus();
}
@@ -2158,7 +2158,7 @@ TQString KNConfig::XHeaderConfDialog::result()
TQString value = v_alue->text();
// just in case someone pastes a newline
value.replace( '\n', ' ' );
- return TQString( "X-%1: %2" ).arg( n_ame->text() ).arg( value );
+ return TQString( "X-%1: %2" ).tqarg( n_ame->text() ).tqarg( value );
}
@@ -2373,10 +2373,10 @@ KNConfig::GroupCleanupWidget::GroupCleanupWidget( Cleanup *data, TQWidget *paren
mExpGroup = new TQGroupBox( i18n("Newsgroup Cleanup Settings"), this );
mExpGroup->setColumnLayout(0, Qt::Vertical );
- mExpGroup->layout()->setSpacing( KDialog::spacingHint() );
- mExpGroup->layout()->setMargin( KDialog::marginHint() );
+ mExpGroup->tqlayout()->setSpacing( KDialog::spacingHint() );
+ mExpGroup->tqlayout()->setMargin( KDialog::marginHint() );
top->addWidget( mExpGroup );
- TQGridLayout *grid = new TQGridLayout( mExpGroup->layout(), 7, 2 );
+ TQGridLayout *grid = new TQGridLayout( mExpGroup->tqlayout(), 7, 2 );
grid->setRowSpacing( 0, KDialog::spacingHint() );
@@ -2482,11 +2482,11 @@ KNConfig::CleanupWidget::CleanupWidget( TQWidget *p, const char *n ) :
TQGroupBox *foldersB=new TQGroupBox(i18n("Folders"), this);
foldersB->setColumnLayout(0, Qt::Vertical );
- foldersB->layout()->setSpacing( KDialog::spacingHint() );
- foldersB->layout()->setMargin( KDialog::marginHint() );
+ foldersB->tqlayout()->setSpacing( KDialog::spacingHint() );
+ foldersB->tqlayout()->setMargin( KDialog::marginHint() );
topL->addWidget(foldersB);
- TQGridLayout *foldersL=new TQGridLayout(foldersB->layout(), 3,2);
+ TQGridLayout *foldersL=new TQGridLayout(foldersB->tqlayout(), 3,2);
foldersL->setRowSpacing( 0, KDialog::spacingHint() );
diff --git a/knode/knconvert.cpp b/knode/knconvert.cpp
index aa730ab7..70d44703 100644
--- a/knode/knconvert.cpp
+++ b/knode/knconvert.cpp
@@ -12,7 +12,7 @@
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
*/
-#include <layout.h>
+#include <tqlayout.h>
#include <tqwidgetstack.h>
#include <tqlabel.h>
#include <tqcheckbox.h>
@@ -73,7 +73,7 @@ KNConvert::KNConvert(const TQString &version)
Unfortunately this version uses a different format for some data-files, so \
in order to keep your existing data it is necessary to convert it first. This is \
now done automatically by KNode. If you want to, a backup of your existing data \
-will be created before the conversion starts.").arg(KNODE_VERSION), w_1);
+will be created before the conversion starts.").tqarg(KNODE_VERSION), w_1);
w1L->addMultiCellWidget(l1, 0,0, 0,2);
c_reateBkup=new TQCheckBox(i18n("Create backup of old data"), w_1);
@@ -96,7 +96,7 @@ will be created before the conversion starts.").arg(KNODE_VERSION), w_1);
w_2=new TQLabel(s_tack);
w_2->setText(i18n("<b>Converting, please wait...</b>"));
- w_2->setAlignment(AlignCenter);
+ w_2->tqsetAlignment(AlignCenter);
s_tack->addWidget(w_2, 2);
w_3=new TQWidget(s_tack);
@@ -224,7 +224,7 @@ void KNConvert::slotTarExited(KProcess *proc)
delete t_ar;
t_ar = 0;
if(success)
- l_og.append(i18n("created backup of the old data-files in %1").arg(b_ackupPath->text()));
+ l_og.append(i18n("created backup of the old data-files in %1").tqarg(b_ackupPath->text()));
else
l_og.append(i18n("backup failed."));
@@ -402,7 +402,7 @@ int KNConvert::Converter04::convertFolder(TQString srcPrefix, TQString dstPrefix
TQCString buff(size+10);
srcMBox.at(oldIdx.so);
int readBytes=srcMBox.readBlock(buff.data(), size);
- buff.at(readBytes)='\0'; //terminate string;
+ buff.tqat(readBytes)='\0'; //terminate string;
//remove "X-KNode-Overview"
int pos=buff.find('\n');
diff --git a/knode/kndisplayedheader.cpp b/knode/kndisplayedheader.cpp
index 65b16522..1f6952f4 100644
--- a/knode/kndisplayedheader.cpp
+++ b/knode/kndisplayedheader.cpp
@@ -107,7 +107,7 @@ void KNDisplayedHeader::setTranslatedName(const TQString &s)
bool retranslated = false;
for (const char **c=predef;(*c)!=0;c++) { // ok, first the standard header names
if (s==i18n("collection of article headers",*c)) {
- n_ame = TQString::fromLatin1(*c);
+ n_ame = TQString::tqfromLatin1(*c);
retranslated = true;
break;
}
@@ -116,7 +116,7 @@ void KNDisplayedHeader::setTranslatedName(const TQString &s)
if (!retranslated) {
for (const char **c=disp;(*c)!=0;c++) // now our standard display names
if (s==i18n("collection of article headers",*c)) {
- n_ame = TQString::fromLatin1(*c);
+ n_ame = TQString::tqfromLatin1(*c);
retranslated = true;
break;
}
diff --git a/knode/knfilterconfigwidget.cpp b/knode/knfilterconfigwidget.cpp
index 3ff50919..3c7daee1 100644
--- a/knode/knfilterconfigwidget.cpp
+++ b/knode/knfilterconfigwidget.cpp
@@ -14,7 +14,7 @@
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
*/
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <klocale.h>
diff --git a/knode/knfilterdialog.cpp b/knode/knfilterdialog.cpp
index 79b0dad7..ea05a21c 100644
--- a/knode/knfilterdialog.cpp
+++ b/knode/knfilterdialog.cpp
@@ -16,7 +16,7 @@
#include <tqlabel.h>
#include <tqcheckbox.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <klocale.h>
#include <kmessagebox.h>
@@ -31,7 +31,7 @@
KNFilterDialog::KNFilterDialog(KNArticleFilter *f, TQWidget *parent, const char *name)
- : KDialogBase(Plain, (f->id()==-1)? i18n("New Filter"):i18n("Properties of %1").arg(f->name()),
+ : KDialogBase(Plain, (f->id()==-1)? i18n("New Filter"):i18n("Properties of %1").tqarg(f->name()),
Ok|Cancel|Help, Ok, parent, name),
fltr(f)
{
@@ -74,8 +74,8 @@ KNFilterDialog::KNFilterDialog(KNArticleFilter *f, TQWidget *parent, const char
fw->messageId->setFilter(f->messageId);
fw->references->setFilter(f->references);
- setFixedHeight(sizeHint().height());
- KNHelper::restoreWindowSize("filterDLG", this, sizeHint());
+ setFixedHeight(tqsizeHint().height());
+ KNHelper::restoreWindowSize("filterDLG", this, tqsizeHint());
setHelp("anc-using-filters");
connect( fname, TQT_SIGNAL( textChanged ( const TQString & )), this, TQT_SLOT( slotTextChanged( const TQString & )));
diff --git a/knode/knfolder.cpp b/knode/knfolder.cpp
index 852fe9ae..58ac7d0f 100644
--- a/knode/knfolder.cpp
+++ b/knode/knfolder.cpp
@@ -44,7 +44,7 @@ KNFolder::KNFolder()
KNFolder::KNFolder(int id, const TQString &name, KNFolder *parent)
: KNArticleCollection(parent), i_d(id), i_ndexDirty(false), w_asOpen(true)
{
- TQString fname=path()+TQString("custom_%1").arg(i_d);
+ TQString fname=path()+TQString("custom_%1").tqarg(i_d);
n_ame = name;
m_boxFile.setName(fname+".mbox");
@@ -63,7 +63,7 @@ KNFolder::KNFolder(int id, const TQString &name, KNFolder *parent)
KNFolder::KNFolder(int id, const TQString &name, const TQString &prefix, KNFolder *parent)
: KNArticleCollection(parent), i_d(id), i_ndexDirty(false), w_asOpen(true)
{
- TQString fname=path()+TQString("%1_%2").arg(prefix).arg(i_d);
+ TQString fname=path()+TQString("%1_%2").tqarg(prefix).tqarg(i_d);
n_ame = name;
m_boxFile.setName(fname+".mbox");
@@ -356,7 +356,7 @@ bool KNFolder::loadArticle(KNLocalArticle *a)
}
//set content
- buff.at(readBytes)='\0'; //terminate string
+ buff.tqat(readBytes)='\0'; //terminate string
a->setContent(buff);
a->parse();
diff --git a/knode/knfoldermanager.cpp b/knode/knfoldermanager.cpp
index 44ae78b4..7041f456 100644
--- a/knode/knfoldermanager.cpp
+++ b/knode/knfoldermanager.cpp
@@ -326,7 +326,7 @@ void KNFolderManager::importFromMBox(KNFolder *f)
int readBytes=file->readBlock(buff.data(), size);
if (readBytes != -1) {
- buff.at(readBytes)='\0'; //terminate string
+ buff.tqat(readBytes)='\0'; //terminate string
art = new KNLocalArticle(0);
art->setEditDisabled(true);
art->setContent(buff);
@@ -345,7 +345,7 @@ void KNFolderManager::importFromMBox(KNFolder *f)
int readBytes=file->readBlock(buff.data(), size);
if (readBytes != -1) {
- buff.at(readBytes)='\0'; //terminate string
+ buff.tqat(readBytes)='\0'; //terminate string
art = new KNLocalArticle(0);
art->setEditDisabled(true);
art->setContent(buff);
diff --git a/knode/kngroup.cpp b/knode/kngroup.cpp
index c306b178..df40915f 100644
--- a/knode/kngroup.cpp
+++ b/knode/kngroup.cpp
@@ -71,7 +71,7 @@ void KNGroup::updateListItem()
if(!l_istItem) return;
l_istItem->setTotalCount( c_ount );
l_istItem->setUnreadCount( c_ount - r_eadCount - i_gnoreCount );
- l_istItem->repaint();
+ l_istItem->tqrepaint();
}
@@ -133,7 +133,7 @@ void KNGroup::saveInfo()
info.writeEntry("dynDataFormat", d_ynDataFormat);
info.writeEntry("name", n_ame);
info.writeEntry("useCharset", u_seCharset);
- info.writeEntry("defaultChSet", TQString::fromLatin1(d_efaultChSet));
+ info.writeEntry("defaultChSet", TQString::tqfromLatin1(d_efaultChSet));
switch (s_tatus) {
case unknown: info.writeEntry("status","unknown");
break;
@@ -964,7 +964,7 @@ void KNGroup::reorganize()
buildThreads(length());
saveStaticData(length(), true);
saveDynamicData(length(), true);
- knGlobals.top->headerView()->repaint();
+ knGlobals.top->headerView()->tqrepaint();
knGlobals.seStatusMsg(TQString());
knGlobals.top->setCursorBusy(false);
}
@@ -1052,7 +1052,7 @@ TQString KNGroup::prepareForExecution()
if (knGlobals.groupManager()->loadHeaders(this))
return TQString();
else
- return i18n("Cannot load saved headers: %1").arg(groupname());
+ return i18n("Cannot load saved headers: %1").tqarg(groupname());
}
//***************************************************************************
diff --git a/knode/kngroup.h b/knode/kngroup.h
index 76a9d0dd..387ff0f6 100644
--- a/knode/kngroup.h
+++ b/knode/kngroup.h
@@ -35,7 +35,7 @@ namespace KNConfig {
class KNGroup : public KNArticleCollection , public KNJobItem {
public:
- enum Status { unknown=0, readOnly=1, postingAllowed=2, moderated=3 };
+ enum tqStatus { unknown=0, readOnly=1, postingAllowed=2, moderated=3 };
KNGroup(KNCollection *p=0);
~KNGroup();
@@ -123,8 +123,8 @@ class KNGroup : public KNArticleCollection , public KNJobItem {
KNNntpAccount* account();
KNConfig::Identity* identity()const { return i_dentity; }
void setIdentity(KNConfig::Identity *i) { i_dentity=i; }
- Status status()const { return s_tatus; }
- void seStatus(Status s) { s_tatus=s; }
+ tqStatus status()const { return s_tatus; }
+ void setqStatus(tqStatus s) { s_tatus=s; }
void showProperties();
// cleanup configuration
@@ -153,7 +153,7 @@ class KNGroup : public KNArticleCollection , public KNJobItem {
bool l_ocked,
u_seCharset;
- Status s_tatus;
+ tqStatus s_tatus;
TQStringList c_rosspostIDBuffer;
diff --git a/knode/kngroupbrowser.cpp b/knode/kngroupbrowser.cpp
index 7c2176e1..a3bcb89f 100644
--- a/knode/kngroupbrowser.cpp
+++ b/knode/kngroupbrowser.cpp
@@ -14,7 +14,7 @@
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
*/
-#include <layout.h>
+#include <tqlayout.h>
#include <tqcheckbox.h>
#include <tqtimer.h>
#include <tqapplication.h>
@@ -92,7 +92,7 @@ KNGroupBrowser::KNGroupBrowser(TQWidget *parent, const TQString &caption, KNNntp
connect(groupView, TQT_SIGNAL(doubleClicked(TQListViewItem*)),
this, TQT_SLOT(slotItemDoubleClicked(TQListViewItem*)));
- //layout
+ //tqlayout
TQGridLayout *topL=new TQGridLayout(page,3,1,0,5);
TQHBoxLayout *filterL=new TQHBoxLayout(10);
TQVBoxLayout *arrL=new TQVBoxLayout(10);
@@ -358,7 +358,7 @@ void KNGroupBrowser::slotFilter(const TQString &txt)
lastFilter = filtertxt;
incrementalFilter = !isRegexp;
- leftLabel->setText(i18n("Groups on %1: (%2 displayed)").arg(a_ccount->name()).arg(matchList->count()));
+ leftLabel->setText(i18n("Groups on %1: (%2 displayed)").tqarg(a_ccount->name()).tqarg(matchList->count()));
arrowBtn1->setEnabled(false);
arrowBtn2->setEnabled(false);
diff --git a/knode/kngroupdialog.cpp b/knode/kngroupdialog.cpp
index d9b25ba1..0050e96a 100644
--- a/knode/kngroupdialog.cpp
+++ b/knode/kngroupdialog.cpp
@@ -15,7 +15,7 @@
*/
#include <tqlabel.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqbuttongroup.h>
#include <tqradiobutton.h>
#include <tqcheckbox.h>
@@ -300,7 +300,7 @@ void KNGroupDialog::slotUser2()
topL->addMultiCellWidget(takeCustom, 2, 2, 0, 1);
KDatePicker *dateSel = new KDatePicker(btnGrp, lastDate);
- dateSel->setMinimumSize(dateSel->sizeHint());
+ dateSel->setMinimumSize(dateSel->tqsizeHint());
topL->addWidget(dateSel, 3, 1, TQt::AlignLeft);
connect(takeCustom, TQT_SIGNAL(toggled(bool)), dateSel, TQT_SLOT(setEnabled(bool)));
@@ -314,7 +314,7 @@ void KNGroupDialog::slotUser2()
if (dlg->exec()) {
if (takeCustom->isChecked())
lastDate = dateSel->date();
- a_ccount->setLastNewFetch(TQDate::currentDate());
+ a_ccount->setLastNewFetch(TQDate::tqcurrentDate());
leftLabel->setText(i18n("Checking for new groups..."));
enableButton(User1,false);
enableButton(User2,false);
diff --git a/knode/kngroupmanager.cpp b/knode/kngroupmanager.cpp
index 4aa6a944..dd8b0596 100644
--- a/knode/kngroupmanager.cpp
+++ b/knode/kngroupmanager.cpp
@@ -51,7 +51,7 @@ KNGroupInfo::KNGroupInfo()
}
-KNGroupInfo::KNGroupInfo(const TQString &n_ame, const TQString &d_escription, bool n_ewGroup, bool s_ubscribed, KNGroup::Status s_tatus)
+KNGroupInfo::KNGroupInfo(const TQString &n_ame, const TQString &d_escription, bool n_ewGroup, bool s_ubscribed, KNGroup::tqStatus s_tatus)
: name(n_ame), description(d_escription), newGroup(n_ewGroup), subscribed(s_ubscribed),
status(s_tatus)
{
@@ -101,7 +101,7 @@ bool KNGroupListData::readIn(KNProtocolClient *client)
int sepPos1,sepPos2;
TQString name,description;
bool sub;
- KNGroup::Status status=KNGroup::unknown;
+ KNGroup::tqStatus status=KNGroup::unknown;
TQTime timer;
uint size=f.size()+2;
@@ -435,7 +435,7 @@ void KNGroupManager::subscribeGroup(const KNGroupInfo *gi, KNNntpAccount *a)
grp=new KNGroup(a);
grp->setGroupname(gi->name);
grp->setDescription(gi->description);
- grp->seStatus(gi->status);
+ grp->setqStatus(gi->status);
grp->saveInfo();
mGroupList.append( grp );
emit groupAdded(grp);
@@ -449,7 +449,7 @@ bool KNGroupManager::unsubscribeGroup(KNGroup *g)
if(!g) return false;
if((g->isLocked()) || (g->lockedArticles()>0)) {
- KMessageBox::sorry(knGlobals.topWidget, i18n("The group \"%1\" is being updated currently.\nIt is not possible to unsubscribe from it at the moment.").arg(g->groupname()));
+ KMessageBox::sorry(knGlobals.topWidget, i18n("The group \"%1\" is being updated currently.\nIt is not possible to unsubscribe from it at the moment.").tqarg(g->groupname()));
return false;
}
@@ -596,7 +596,7 @@ void KNGroupManager::processJob(KNJobData *j)
for ( KNGroupInfo* inf = d->groups->first(); inf; inf = d->groups->next() )
if ( inf->name == (*it)->groupname() ) {
(*it)->setDescription( inf->description );
- (*it)->seStatus( inf->status );
+ (*it)->setqStatus( inf->status );
break;
}
}
diff --git a/knode/kngroupmanager.h b/knode/kngroupmanager.h
index c6ccc92f..8b34979d 100644
--- a/knode/kngroupmanager.h
+++ b/knode/kngroupmanager.h
@@ -38,13 +38,13 @@ class KNGroupInfo {
public:
KNGroupInfo();
- KNGroupInfo(const TQString &n_ame, const TQString &d_escription, bool n_ewGroup=false, bool s_ubscribed=false, KNGroup::Status s_tatus=KNGroup::unknown );
+ KNGroupInfo(const TQString &n_ame, const TQString &d_escription, bool n_ewGroup=false, bool s_ubscribed=false, KNGroup::tqStatus s_tatus=KNGroup::unknown );
~KNGroupInfo();
/** group names will be utf-8 encoded in the future... */
TQString name,description;
bool newGroup, subscribed;
- KNGroup::Status status;
+ KNGroup::tqStatus status;
bool operator== (const KNGroupInfo &gi2);
bool operator< (const KNGroupInfo &gi2);
diff --git a/knode/kngrouppropdlg.cpp b/knode/kngrouppropdlg.cpp
index 8e18802a..c0a107af 100644
--- a/knode/kngrouppropdlg.cpp
+++ b/knode/kngrouppropdlg.cpp
@@ -13,7 +13,7 @@
*/
#include <tqgroupbox.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqvbox.h>
#include <tqcheckbox.h>
@@ -30,7 +30,7 @@
KNGroupPropDlg::KNGroupPropDlg(KNGroup *group, TQWidget *parent, const char *name )
- : KDialogBase(Tabbed, i18n("Properties of %1").arg(group->groupname()),
+ : KDialogBase(Tabbed, i18n("Properties of %1").tqarg(group->groupname()),
Ok|Cancel|Help, Ok, parent, name),
g_rp(group), n_ickChanged(false)
{
@@ -152,7 +152,7 @@ KNGroupPropDlg::KNGroupPropDlg(KNGroup *group, TQWidget *parent, const char *nam
cleanupLayout->addWidget( mCleanupWidget );
cleanupLayout->addStretch( 1 );
- KNHelper::restoreWindowSize("groupPropDLG", this, sizeHint());
+ KNHelper::restoreWindowSize("groupPropDLG", this, tqsizeHint());
}
diff --git a/knode/kngroupselectdialog.cpp b/knode/kngroupselectdialog.cpp
index 595fe045..6767d3f6 100644
--- a/knode/kngroupselectdialog.cpp
+++ b/knode/kngroupselectdialog.cpp
@@ -14,7 +14,7 @@
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
*/
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqheader.h>
#include <tqcheckbox.h>
diff --git a/knode/knhdrviewitem.cpp b/knode/knhdrviewitem.cpp
index 6330b89a..cf2713b8 100644
--- a/knode/knhdrviewitem.cpp
+++ b/knode/knhdrviewitem.cpp
@@ -114,7 +114,7 @@ int KNHdrViewItem::compare( TQListViewItem *i, int col, bool ) const
}
-void KNHdrViewItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int width, int alignment )
+void KNHdrViewItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column, int width, int tqalignment )
{
int xText = 0, xPM = 3, yPM = 0;
TQColor base;
@@ -159,7 +159,7 @@ void KNHdrViewItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column,
TQString t2;
TQFont f2;
if (countUnreadInThread() > 0 && column == paintInfo->subCol && !isOpen()) {
- t2 = TQString( " (%1)" ).arg( countUnreadInThread() );
+ t2 = TQString( " (%1)" ).tqarg( countUnreadInThread() );
f2 = p->font();
f2.setBold( true );
cntWidth = TQFontMetrics( f2 ).width( t2, -1 );
@@ -172,7 +172,7 @@ void KNHdrViewItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column,
else
mShowToolTip[column] = false;
- p->drawText( xText, 0, width - xText - 5, height(), alignment | AlignVCenter, t );
+ p->drawText( xText, 0, width - xText - 5, height(), tqalignment | AlignVCenter, t );
if (cntWidth) {
TQFont orig = p->font();
p->setFont( f2 );
@@ -183,7 +183,7 @@ void KNHdrViewItem::paintCell( TQPainter *p, const TQColorGroup &cg, int column,
pen.setColor( cg.link() );
}
p->setPen( pen );
- p->drawText( xText + TQFontMetrics( orig ).width( t, -1 ), 0, width - xText - 5, height(), alignment | AlignVCenter, t2 );
+ p->drawText( xText + TQFontMetrics( orig ).width( t, -1 ), 0, width - xText - 5, height(), tqalignment | AlignVCenter, t2 );
}
}
}
diff --git a/knode/knhdrviewitem.h b/knode/knhdrviewitem.h
index 476c6d53..163a4507 100644
--- a/knode/knhdrviewitem.h
+++ b/knode/knhdrviewitem.h
@@ -33,7 +33,7 @@ class KNHdrViewItem : public KListViewItem {
virtual int compare(TQListViewItem *i, int col, bool ascending) const;
- void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int alignment);
+ void paintCell(TQPainter *p, const TQColorGroup &cg, int column, int width, int tqalignment);
int width(const TQFontMetrics &fm, const TQListView *lv, int column);
virtual TQString text( int col ) const;
diff --git a/knode/knjobdata.cpp b/knode/knjobdata.cpp
index 8d2c47bf..a5cdac89 100644
--- a/knode/knjobdata.cpp
+++ b/knode/knjobdata.cpp
@@ -24,7 +24,7 @@
#include "knnetaccess.h"
#include "knnntpaccount.h"
-#include <stylesheet.h>
+#include <tqstylesheet.h>
KNJobConsumer::KNJobConsumer()
{
@@ -95,7 +95,7 @@ void KNJobData::cancel()
mJob = 0;
}
if ( mProgressItem ) {
- mProgressItem->seStatus( "Canceled" );
+ mProgressItem->setqStatus( "Canceled" );
mProgressItem->setComplete();
mProgressItem = 0;
}
@@ -140,7 +140,7 @@ void KNJobData::slotJobPercent( KIO::Job*, unsigned long percent )
void KNJobData::slotJobInfoMessage( KIO::Job*, const TQString &msg )
{
kdDebug(5003) << k_funcinfo << "Status: " << msg << endl;
- seStatus( msg );
+ setqStatus( msg );
}
diff --git a/knode/knjobdata.h b/knode/knjobdata.h
index 7f14dc7b..ade7b7f3 100644
--- a/knode/knjobdata.h
+++ b/knode/knjobdata.h
@@ -115,7 +115,7 @@ class KNJobData : public TQObject
void createProgressItem();
// safe forwards to the progress item
- void seStatus( const TQString &msg ) { if ( mProgressItem ) mProgressItem->seStatus( msg ); }
+ void setqStatus( const TQString &msg ) { if ( mProgressItem ) mProgressItem->setqStatus( msg ); }
void setProgress( unsigned int progress ) { if ( mProgressItem ) mProgressItem->setProgress( progress ); }
void setComplete() { if ( mProgressItem ) { mProgressItem->setComplete(); mProgressItem = 0; } }
diff --git a/knode/knmainwidget.cpp b/knode/knmainwidget.cpp
index 21ead952..4294f7a5 100644
--- a/knode/knmainwidget.cpp
+++ b/knode/knmainwidget.cpp
@@ -14,7 +14,7 @@
#include "knmainwidget.h"
#include <tqhbox.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <ktoolbar.h>
#include <kinputdialog.h>
@@ -305,19 +305,19 @@ KNMainWidget::~KNMainWidget()
void KNMainWidget::iniStatusBar()
{
//statusbar
- KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+ KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
KStatusBar *sb = mainWin ? mainWin->statusBar() : 0;
s_tatusFilter = new KRSqueezedTextLabel( TQString(), sb );
- s_tatusFilter->setAlignment( AlignLeft | AlignVCenter );
+ s_tatusFilter->tqsetAlignment( AlignLeft | AlignVCenter );
s_tatusGroup = new KRSqueezedTextLabel( TQString(), sb );
- s_tatusGroup->setAlignment( AlignLeft | AlignVCenter );
+ s_tatusGroup->tqsetAlignment( AlignLeft | AlignVCenter );
}
//================================== GUI =================================
void KNMainWidget::seStatusMsg(const TQString& text, int id)
{
- KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+ KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
KStatusBar *bar = mainWin ? mainWin->statusBar() : 0;
if ( !bar )
return;
@@ -342,7 +342,7 @@ void KNMainWidget::seStatusMsg(const TQString& text, int id)
void KNMainWidget::seStatusHelpMsg(const TQString& text)
{
- KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+ KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
KStatusBar *bar = mainWin ? mainWin->statusBar() : 0;
if ( bar )
bar->message(text, 2000);
@@ -375,7 +375,7 @@ void KNMainWidget::setCursorBusy(bool b)
void KNMainWidget::blockUI(bool b)
{
b_lockui = b;
- KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+ KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
KMenuBar *mbar = mainWin ? mainWin->menuBar() : 0;
if ( mbar )
mbar->setEnabled(!b);
@@ -394,7 +394,7 @@ void KNMainWidget::blockUI(bool b)
void KNMainWidget::disableAccels(bool b)
{
a_ccel->setEnabled(!b);
- KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+ KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
KAccel *naccel = mainWin ? mainWin->accel() : 0;
if ( naccel )
naccel->setEnabled(!b);
@@ -409,7 +409,7 @@ void KNMainWidget::disableAccels(bool b)
void KNMainWidget::secureProcessEvents()
{
b_lockui = true;
- KMainWindow *mainWin = dynamic_cast<KMainWindow*>(topLevelWidget());
+ KMainWindow *mainWin = dynamic_cast<KMainWindow*>(tqtopLevelWidget());
KMenuBar *mbar = mainWin ? mainWin->menuBar() : 0;
if ( mbar )
mbar->setEnabled(false);
@@ -431,7 +431,7 @@ void KNMainWidget::secureProcessEvents()
}
-TQSize KNMainWidget::sizeHint() const
+TQSize KNMainWidget::tqsizeHint() const
{
return TQSize(759,478); // default optimized for 800x600
}
@@ -775,7 +775,7 @@ bool KNMainWidget::firstStart()
emailConf.setGroup("Defaults");
TQString group = emailConf.readEntry("Profile","Default");
- emailConf.setGroup(TQString("PROFILE_%1").arg(group));
+ emailConf.setGroup(TQString("PROFILE_%1").tqarg(group));
KNConfig::Identity *id=knGlobals.configManager()->identity();
id->setName(emailConf.readEntry("FullName"));
id->setEmail(emailConf.readEntry("EmailAddress").latin1());
@@ -903,7 +903,7 @@ bool KNMainWidget::queryClose()
void KNMainWidget::showEvent(TQShowEvent *)
{
- slotCheckDockWidgeStatus();
+ slotCheckDockWidgetqStatus();
}
@@ -1301,7 +1301,7 @@ void KNMainWidget::slotNetworkActive(bool b)
}
-void KNMainWidget::slotCheckDockWidgeStatus()
+void KNMainWidget::slotCheckDockWidgetqStatus()
{
a_ctToggleGroupView->setChecked(c_olDock->isVisible());
a_ctToggleArticleViewer->setChecked(a_rtDock->isVisible());
@@ -1511,7 +1511,7 @@ void KNMainWidget::slotGrpUnsubscribe()
kdDebug(5003) << "KNMainWidget::slotGrpUnsubscribe()" << endl;
if(g_rpManager->currentGroup()) {
if(KMessageBox::Yes==KMessageBox::questionYesNo(knGlobals.topWidget,
- i18n("Do you really want to unsubscribe from %1?").arg(g_rpManager->currentGroup()->groupname()), TQString(), i18n("Unsubscribe"), KStdGuiItem::cancel()))
+ i18n("Do you really want to unsubscribe from %1?").tqarg(g_rpManager->currentGroup()->groupname()), TQString(), i18n("Unsubscribe"), KStdGuiItem::cancel()))
if (g_rpManager->unsubscribeGroup(g_rpManager->currentGroup()))
slotCollectionSelected(0);
}
@@ -1588,7 +1588,7 @@ void KNMainWidget::slotFolDelete()
KMessageBox::sorry(knGlobals.topWidget, i18n("You cannot delete a standard folder."));
else if( KMessageBox::Continue==KMessageBox::warningContinueCancel(knGlobals.topWidget,
- i18n("Do you really want to delete this folder and all its children?"),"",KGuiItem(i18n("&Delete"),"editdelete")) ) {
+ i18n("Do you really want to delete this folder and all its tqchildren?"),"",KGuiItem(i18n("&Delete"),"editdelete")) ) {
if(!f_olManager->deleteFolder(f_olManager->currentFolder()))
KMessageBox::sorry(knGlobals.topWidget,
@@ -1639,7 +1639,7 @@ void KNMainWidget::slotFolEmpty()
return;
}
if( KMessageBox::Continue == KMessageBox::warningContinueCancel(
- this, i18n("Do you really want to delete all articles in %1?").arg(f_olManager->currentFolder()->name()),"",KGuiItem(i18n("&Delete"),"editdelete")) )
+ this, i18n("Do you really want to delete all articles in %1?").tqarg(f_olManager->currentFolder()->name()),"",KGuiItem(i18n("&Delete"),"editdelete")) )
f_olManager->emptyFolder(f_olManager->currentFolder());
}
}
@@ -1948,7 +1948,7 @@ void KNMainWidget::slotFetchArticleWithID()
TQString id = dlg->messageId().simplifyWhiteSpace();
if (id.find(TQRegExp("*@*",false,true))!=-1) {
if (id.find(TQRegExp("<*>",false,true))==-1) // add "<>" when necessary
- id = TQString("<%1>").arg(id);
+ id = TQString("<%1>").tqarg(id);
if(!KNArticleWindow::raiseWindowForArticle(id.latin1())) { //article not yet opened
KNRemoteArticle *a=new KNRemoteArticle(g_rpManager->currentGroup());
@@ -1966,7 +1966,7 @@ void KNMainWidget::slotFetchArticleWithID()
void KNMainWidget::slotToggleGroupView()
{
c_olDock->changeHideShowState();
- slotCheckDockWidgeStatus();
+ slotCheckDockWidgetqStatus();
}
@@ -1977,19 +1977,19 @@ void KNMainWidget::slotToggleHeaderView()
if ( !h_drDock->isDockBackPossible() ) {
h_drDock->manualDock( a_rtDock, KDockWidget::DockTop );
h_drDock->makeDockVisible();
- slotCheckDockWidgeStatus();
+ slotCheckDockWidgetqStatus();
return;
}
h_drDock->changeHideShowState();
- slotCheckDockWidgeStatus();
+ slotCheckDockWidgetqStatus();
}
void KNMainWidget::slotToggleArticleViewer()
{
a_rtDock->changeHideShowState();
- slotCheckDockWidgeStatus();
+ slotCheckDockWidgetqStatus();
}
void KNMainWidget::slotToggleQuickSearch()
diff --git a/knode/knmainwidget.h b/knode/knmainwidget.h
index 6a6e8ed1..c00c6998 100644
--- a/knode/knmainwidget.h
+++ b/knode/knmainwidget.h
@@ -83,7 +83,7 @@ public:
void secureProcessEvents();
/** useful default value */
- virtual TQSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
/** handle URL given as command-line argument */
void openURL(const KURL &url);
@@ -230,7 +230,7 @@ protected slots:
void slotNetworkActive(bool b);
//dock widget slots
- void slotCheckDockWidgeStatus();
+ void slotCheckDockWidgetqStatus();
void slotGroupDockHidden();
void slotHeaderDockHidden();
void slotArticleDockHidden();
diff --git a/knode/knmemorymanager.cpp b/knode/knmemorymanager.cpp
index 37a63928..365e9f8c 100644
--- a/knode/knmemorymanager.cpp
+++ b/knode/knmemorymanager.cpp
@@ -162,7 +162,7 @@ void KNMemoryManager::checkMemoryUsageCollections()
for ( TQValueList<CollectionItem*>::Iterator it = tempList.begin(); it != tempList.end(); ) {
if ( c_ollCacheSize <= maxSize )
break;
- // unloadHeaders() will remove the cache entry and thus invalidate the iterator!
+ // unloadHeaders() will remove the cache entry and thus tqinvalidate the iterator!
c = (*it)->col;
++it;
@@ -191,7 +191,7 @@ void KNMemoryManager::checkMemoryUsageArticles()
for ( TQValueList<ArticleItem*>::Iterator it = mArtList.begin(); it != mArtList.end(); ) {
if ( a_rtCacheSize <= maxSize )
break;
- // unloadArticle() will remove the cache entry and thus invalidate the iterator!
+ // unloadArticle() will remove the cache entry and thus tqinvalidate the iterator!
KNArticle *art = (*it)->art;
++it;
knGlobals.articleManager()->unloadArticle( art, false ); // *try* to unload
diff --git a/knode/knnetaccess.cpp b/knode/knnetaccess.cpp
index 1b67d62e..ec2c8663 100644
--- a/knode/knnetaccess.cpp
+++ b/knode/knnetaccess.cpp
@@ -102,7 +102,7 @@ void KNNetAccess::addJob(KNJobData *job)
if ( !job->account()->readyForLogin() ) {
mWalletQueue.append( job );
knGlobals.accountManager()->loadPasswordsAsync();
- job->seStatus( i18n( "Waiting for KWallet..." ) );
+ job->setqStatus( i18n( "Waiting for KWallet..." ) );
return;
}
@@ -142,7 +142,7 @@ void KNNetAccess::addJob(KNJobData *job)
startJobNntp();
}
}
- updateStatus();
+ updatetqStatus();
}
@@ -178,7 +178,7 @@ void KNNetAccess::stopJobsNntp( int type )
} else
++it;
}
- updateStatus();
+ updatetqStatus();
}
@@ -207,7 +207,7 @@ void KNNetAccess::stopJobsSmtp( int type )
} else
++it;
}
- updateStatus();
+ updatetqStatus();
}
@@ -340,7 +340,7 @@ void KNNetAccess::threadDoneNntp()
if (!nntpJobQueue.isEmpty())
startJobNntp();
- updateStatus();
+ updatetqStatus();
}
@@ -368,7 +368,7 @@ void KNNetAccess::threadDoneSmtp()
if (!smtpJobQueue.isEmpty())
startJobSmtp();
- updateStatus();
+ updatetqStatus();
}
@@ -399,52 +399,52 @@ void KNNetAccess::slotThreadSignal(int i)
case KNProtocolClient::TSconnect:
currMsg = i18n(" Connecting to server...");
knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ currentNntpJob->setqStatus(currMsg);
break;
case KNProtocolClient::TSloadGrouplist:
currMsg = i18n(" Loading group list from disk...");
knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ currentNntpJob->setqStatus(currMsg);
break;
case KNProtocolClient::TSwriteGrouplist:
currMsg = i18n(" Writing group list to disk...");
knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ currentNntpJob->setqStatus(currMsg);
break;
case KNProtocolClient::TSdownloadGrouplist:
currMsg = i18n(" Downloading group list...");
knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ currentNntpJob->setqStatus(currMsg);
break;
case KNProtocolClient::TSdownloadNewGroups:
currMsg = i18n(" Looking for new groups...");
knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ currentNntpJob->setqStatus(currMsg);
break;
case KNProtocolClient::TSdownloadDesc:
currMsg = i18n(" Downloading group descriptions...");
knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ currentNntpJob->setqStatus(currMsg);
break;
case KNProtocolClient::TSdownloadNew:
currMsg = i18n(" Downloading new headers...");
knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ currentNntpJob->setqStatus(currMsg);
break;
case KNProtocolClient::TSsortNew:
currMsg = i18n(" Sorting...");
knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ currentNntpJob->setqStatus(currMsg);
break;
case KNProtocolClient::TSdownloadArticle:
currMsg = i18n(" Downloading article...");
knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ currentNntpJob->setqStatus(currMsg);
break;
case KNProtocolClient::TSsendArticle:
currMsg = i18n(" Sending article...");
knGlobals.seStatusMsg(currMsg);
- currentNntpJob->seStatus(currMsg);
+ currentNntpJob->setqStatus(currMsg);
break;
case KNProtocolClient::TSjobStarted:
currentNntpJob->setProgress(0);
@@ -477,7 +477,7 @@ void KNNetAccess::slotPasswordsChanged()
{
TQValueList<KNJobData*>::ConstIterator it;
for ( it = mWalletQueue.begin(); it != mWalletQueue.end(); ++it ) {
- (*it)->seStatus( i18n("Waiting...") );
+ (*it)->setqStatus( i18n("Waiting...") );
if ( (*it)->type() == KNJobData::JTmail )
smtpJobQueue.append( (*it) );
else
@@ -528,10 +528,10 @@ void KNNetAccess::slotCancelJob( KPIM::ProgressItem *item )
if ( currentSmtpJob && currentSmtpJob->progressItem() == item )
cancelCurrentSmtpJob();
- updateStatus();
+ updatetqStatus();
}
-void KNNetAccess::updateStatus( )
+void KNNetAccess::updatetqStatus( )
{
if ( nntpJobQueue.isEmpty() && smtpJobQueue.isEmpty() && !currentNntpJob
&& !currentSmtpJob && mWalletQueue.isEmpty() )
diff --git a/knode/knnetaccess.h b/knode/knnetaccess.h
index 23e34e0c..6b34937a 100644
--- a/knode/knnetaccess.h
+++ b/knode/knnetaccess.h
@@ -85,7 +85,7 @@ class KNNetAccess : public TQObject {
void cancelCurrentNntpJob( int type = 0 );
void cancelCurrentSmtpJob( int type = 0 );
/** Update activitiy status, i.e. emit netActive signal. */
- void updateStatus();
+ void updatetqStatus();
private slots:
void slotJobResult( KIO::Job *job );
diff --git a/knode/knnntpaccount.cpp b/knode/knnntpaccount.cpp
index ba1657c0..81b3cc42 100644
--- a/knode/knnntpaccount.cpp
+++ b/knode/knnntpaccount.cpp
@@ -75,7 +75,7 @@ void KNNntpAccountIntervalChecking::slotCheckNews()
KNNntpAccount::KNNntpAccount()
: KNCollection(0), KNServerInfo(), i_dentity(0), f_etchDescriptions(true), w_asOpen(false), i_ntervalChecking(false), c_heckInterval(10)
{
- l_astNewFetch = TQDate::currentDate();
+ l_astNewFetch = TQDate::tqcurrentDate();
a_ccountIntervalChecking = new KNNntpAccountIntervalChecking(this);
mCleanupConf = new KNConfig::Cleanup( false );
}
@@ -174,7 +174,7 @@ void KNNntpAccount::saveInfo()
TQString KNNntpAccount::path()
{
- TQString dir(locateLocal("data","knode/")+TQString("nntp.%1/").arg(i_d));
+ TQString dir(locateLocal("data","knode/")+TQString("nntp.%1/").tqarg(i_d));
if (dir.isNull())
KNHelper::displayInternalFileError();
return (dir);
diff --git a/knode/knnntpclient.cpp b/knode/knnntpclient.cpp
index d49f9053..26473b6a 100644
--- a/knode/knnntpclient.cpp
+++ b/knode/knnntpclient.cpp
@@ -16,7 +16,7 @@
#include <stdlib.h>
#include <klocale.h>
-#include <textcodec.h>
+#include <tqtextcodec.h>
#include <tqmutex.h>
#include "kngroupmanager.h"
@@ -93,7 +93,7 @@ void KNNntpClient::doFetchGroups()
char *s, *line;
TQString name;
- KNGroup::Status status;
+ KNGroup::tqStatus status;
bool subscribed;
while (getNextLine()) {
@@ -228,7 +228,7 @@ void KNNntpClient::doCheckNewGroups()
char *s, *line;
TQString name;
- KNGroup::Status status;
+ KNGroup::tqStatus status;
TQSortedList<KNGroupInfo> tmpList;
tmpList.setAutoDelete(true);
@@ -336,7 +336,7 @@ void KNNntpClient::doFetchNewHeaders()
sendSignal(TSdownloadNew);
errorPrefix=i18n("No new articles could be retrieved for\n%1/%2.\nThe following error occurred:\n")
- .arg(account.server()).arg(target->groupname());
+ .tqarg(account.server()).tqarg(target->groupname());
cmd="GROUP ";
cmd+=target->groupname().utf8();
@@ -482,7 +482,7 @@ void KNNntpClient::doFetchArticle()
job->setErrorString( errorPrefix + getCurrentLine() +
i18n("<br><br>The article you requested is not available on your news server."
"<br>You could try to get it from <a href=\"http://groups.google.com/groups?selm=%1\">groups.google.com</a>.")
- .arg( msgId ) );
+ .tqarg( msgId ) );
}
return;
}
@@ -638,7 +638,7 @@ bool KNNntpClient::openConnection()
#ifndef NDEBUG
qDebug("knode: Authorization failed");
#endif
- job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").arg(getCurrentLine()));
+ job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").tqarg(getCurrentLine()));
job->setAuthError(true);
closeConnection();
return false;
@@ -695,7 +695,7 @@ bool KNNntpClient::sendCommand(const TQCString &cmd, int &rep)
//qDebug("knode: Password required");
if (!account.pass().length()) {
- job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").arg(getCurrentLine()));
+ job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").tqarg(getCurrentLine()));
job->setAuthError(true);
closeConnection();
return false;
@@ -716,7 +716,7 @@ bool KNNntpClient::sendCommand(const TQCString &cmd, int &rep)
if (!KNProtocolClient::sendCommand(cmd,rep)) // retry the original command
return false;
} else {
- job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").arg(getCurrentLine()));
+ job->setErrorString(i18n("Authentication failed.\nCheck your username and password.\n\n%1").tqarg(getCurrentLine()));
job->setAuthError(true);
closeConnection();
return false;
@@ -729,7 +729,7 @@ bool KNNntpClient::sendCommand(const TQCString &cmd, int &rep)
void KNNntpClient::handleErrors()
{
if (errorPrefix.isEmpty())
- job->setErrorString(i18n("An error occurred:\n%1").arg(getCurrentLine()));
+ job->setErrorString(i18n("An error occurred:\n%1").tqarg(getCurrentLine()));
else
job->setErrorString(errorPrefix + getCurrentLine());
diff --git a/knode/knode.cpp b/knode/knode.cpp
index 1af62747..e0963816 100644
--- a/knode/knode.cpp
+++ b/knode/knode.cpp
@@ -109,7 +109,7 @@ void KNMainWindow::setupStatusBar()
statusBar()->addWidget( mLittleProgress, 0 , true );
mStatusMsgLabel = new KRSqueezedTextLabel( TQString(), statusBar() );
- mStatusMsgLabel->setAlignment( AlignLeft | AlignVCenter );
+ mStatusMsgLabel->tqsetAlignment( AlignLeft | AlignVCenter );
statusBar()->addWidget( mStatusMsgLabel, 2 );
statusBar()->addWidget(m_mainWidget->statusBarLabelFilter(), 2);
statusBar()->addWidget(m_mainWidget->statusBarLabelGroup(), 3);
diff --git a/knode/knode_part.cpp b/knode/knode_part.cpp
index 1268733c..b20a5bb8 100644
--- a/knode/knode_part.cpp
+++ b/knode/knode_part.cpp
@@ -41,7 +41,7 @@
#include <kstatusbar.h>
#include <krsqueezedtextlabel.h>
-#include <layout.h>
+#include <tqlayout.h>
typedef KParts::GenericFactory< KNodePart > KNodeFactory;
diff --git a/knode/knprotocolclient.cpp b/knode/knprotocolclient.cpp
index 330199bd..dd0db677 100644
--- a/knode/knprotocolclient.cpp
+++ b/knode/knprotocolclient.cpp
@@ -201,11 +201,11 @@ bool KNProtocolClient::openConnection()
if (ks.status() == IO_LookupError) {
job->setErrorString(i18n("Unable to resolve hostname"));
} else if (ks.status() == IO_ConnectError) {
- job->setErrorString(i18n("Unable to connect:\n%1").arg(KExtendedSocket::strError(ks.status(), errno)));
+ job->setErrorString(i18n("Unable to connect:\n%1").tqarg(KExtendedSocket::strError(ks.status(), errno)));
} else if (ks.status() == IO_TimeOutError)
job->setErrorString(i18n("A delay occurred which exceeded the\ncurrent timeout limit."));
else
- job->setErrorString(i18n("Unable to connect:\n%1").arg(KExtendedSocket::strError(ks.status(), errno)));
+ job->setErrorString(i18n("Unable to connect:\n%1").tqarg(KExtendedSocket::strError(ks.status(), errno)));
closeSocket();
return false;
@@ -432,7 +432,7 @@ bool KNProtocolClient::checkNextResponse(int code)
void KNProtocolClient::handleErrors()
{
if (errorPrefix.isEmpty())
- job->setErrorString(i18n("An error occurred:\n%1").arg(thisLine));
+ job->setErrorString(i18n("An error occurred:\n%1").tqarg(thisLine));
else
job->setErrorString(errorPrefix + thisLine);
diff --git a/knode/knrangefilter.cpp b/knode/knrangefilter.cpp
index ef9b611e..28c67b03 100644
--- a/knode/knrangefilter.cpp
+++ b/knode/knrangefilter.cpp
@@ -15,7 +15,7 @@
*/
#include <tqlabel.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqcheckbox.h>
#include <tqcombobox.h>
@@ -118,7 +118,7 @@ KNRangeFilterWidget::KNRangeFilterWidget(const TQString& value, int min, int max
op2->insertItem("<=");
des=new TQLabel(value, this);
- des->setAlignment(AlignCenter);
+ des->tqsetAlignment(AlignCenter);
TQGridLayout *topL=new TQGridLayout(this, 2,6, 8,5 );
diff --git a/knode/knsearchdialog.cpp b/knode/knsearchdialog.cpp
index f4e3bbb3..4344cbba 100644
--- a/knode/knsearchdialog.cpp
+++ b/knode/knsearchdialog.cpp
@@ -14,7 +14,7 @@
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
*/
-#include <layout.h>
+#include <tqlayout.h>
#include <tqcheckbox.h>
#include <klocale.h>
@@ -68,8 +68,8 @@ KNSearchDialog::KNSearchDialog(searchType /*t*/, TQWidget *parent)
f_ilter->setLoaded(true);
f_ilter->setSearchFilter(true);
- setFixedHeight(sizeHint().height());
- KNHelper::restoreWindowSize("searchDlg", this, sizeHint());
+ setFixedHeight(tqsizeHint().height());
+ KNHelper::restoreWindowSize("searchDlg", this, tqsizeHint());
fcw->setStartFocus();
}
diff --git a/knode/knserverinfo.cpp b/knode/knserverinfo.cpp
index d314a771..c0351349 100644
--- a/knode/knserverinfo.cpp
+++ b/knode/knserverinfo.cpp
@@ -111,7 +111,7 @@ void KNServerInfo::saveConf(KConfig *conf)
"but should not be considered secure from decryption efforts "
"if access to the configuration file is obtained.\n"
"Do you want to store the password for server '%1' in the "
- "configuration file?").arg( server() ),
+ "configuration file?").tqarg( server() ),
i18n("KWallet Not Available"),
KGuiItem( i18n("Store Password") ),
KGuiItem( i18n("Do Not Store Password") ) )
diff --git a/knode/knstatusfilter.cpp b/knode/knstatusfilter.cpp
index e99d764c..a1379a26 100644
--- a/knode/knstatusfilter.cpp
+++ b/knode/knstatusfilter.cpp
@@ -14,7 +14,7 @@
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
*/
-#include <layout.h>
+#include <tqlayout.h>
#include <tqcheckbox.h>
#include <klocale.h>
#include <ksimpleconfig.h>
diff --git a/knode/knstringfilter.cpp b/knode/knstringfilter.cpp
index 322840b2..4f69f7ea 100644
--- a/knode/knstringfilter.cpp
+++ b/knode/knstringfilter.cpp
@@ -13,7 +13,7 @@
*/
#include <tqcombobox.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqcheckbox.h>
#include <klocale.h>
diff --git a/knode/knwidgets.cpp b/knode/knwidgets.cpp
index b4c9a160..c3f21959 100644
--- a/knode/knwidgets.cpp
+++ b/knode/knwidgets.cpp
@@ -107,10 +107,10 @@ void KNDialogListBox::keyPressEvent(TQKeyEvent *e)
//====================================================================================
-KNDockWidgetHeaderDrag::KNDockWidgetHeaderDrag(TQWidget *focusWidget, KDockWidgetAbstractHeader* parent, KDockWidget* dock, const char* name )
+KNDockWidgetHeaderDrag::KNDockWidgetHeaderDrag(TQWidget *tqfocusWidget, KDockWidgetAbstractHeader* parent, KDockWidget* dock, const char* name )
: KDockWidgetHeaderDrag(parent, dock, name), f_ocus(false)
{
- connect(focusWidget, TQT_SIGNAL(focusChanged(TQFocusEvent*)), TQT_SLOT(slotFocusChanged(TQFocusEvent*)));
+ connect(tqfocusWidget, TQT_SIGNAL(focusChanged(TQFocusEvent*)), TQT_SLOT(slotFocusChanged(TQFocusEvent*)));
}
@@ -141,9 +141,9 @@ void KNDockWidgetHeaderDrag::paintEvent(TQPaintEvent* ev)
TQPainter paint;
paint.begin(&drawBuffer);
- paint.fillRect(drawBuffer.rect(), TQBrush(colorGroup().brush(TQColorGroup::Background)));
+ paint.fillRect(drawBuffer.rect(), TQBrush(tqcolorGroup().brush(TQColorGroup::Background)));
- paint.setPen(palette().active().highlight());
+ paint.setPen(tqpalette().active().highlight());
paint.drawLine(1, 2, width(), 2);
paint.drawLine(1, 3, width(), 3);
paint.drawLine(1, 5, width(), 5);
diff --git a/knode/knwidgets.h b/knode/knwidgets.h
index e9e782e2..002e3137 100644
--- a/knode/knwidgets.h
+++ b/knode/knwidgets.h
@@ -72,7 +72,7 @@ class KNDockWidgetHeaderDrag : public KDockWidgetHeaderDrag
TQ_OBJECT
public:
- KNDockWidgetHeaderDrag(TQWidget *focusWidget, KDockWidgetAbstractHeader* parent, KDockWidget* dock,
+ KNDockWidgetHeaderDrag(TQWidget *tqfocusWidget, KDockWidgetAbstractHeader* parent, KDockWidget* dock,
const char* name = 0);
virtual ~KNDockWidgetHeaderDrag();
diff --git a/knode/smtpaccountwidget_base.ui b/knode/smtpaccountwidget_base.ui
index 54ffb5e4..b742d4dd 100644
--- a/knode/smtpaccountwidget_base.ui
+++ b/knode/smtpaccountwidget_base.ui
@@ -86,7 +86,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="sizeHint">
+ <property name="tqsizeHint">
<size>
<width>20</width>
<height>40</height>
diff --git a/knode/utilities.cpp b/knode/utilities.cpp
index 49454c0e..2297387b 100644
--- a/knode/utilities.cpp
+++ b/knode/utilities.cpp
@@ -12,7 +12,7 @@
Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
*/
-#include <layout.h>
+#include <tqlayout.h>
#include <tqregexp.h>
#include <tqapplication.h>
#include <tqcursor.h>
@@ -167,7 +167,7 @@ TQFile* KNSaveHelper::getFile(const TQString &dialogTitle)
if (url.isLocalFile()) {
if (TQFileInfo(url.path()).exists() &&
(KMessageBox::warningContinueCancel(knGlobals.topWidget,
- i18n("<qt>A file named <b>%1</b> already exists.<br>Do you want to replace it?</qt>").arg(url.path()),
+ i18n("<qt>A file named <b>%1</b> already exists.<br>Do you want to replace it?</qt>").tqarg(url.path()),
dialogTitle, i18n("&Replace")) != KMessageBox::Continue)) {
return 0;
}
@@ -293,7 +293,7 @@ int KNHelper::selectDialog(TQWidget *parent, const TQString &caption, const TQSt
return ret;
}
-// **** window geometry managing *********************************************
+// **** window tqgeometry managing *********************************************
void KNHelper::saveWindowSize(const TQString &name, const TQSize &s)
{
diff --git a/knode/headerview.cpp b/knode/headerview.cpp
index 324e9d3e..78b46a4c 100644
--- a/knode/headerview.cpp
+++ b/knode/headerview.cpp
@@ -14,7 +14,7 @@
#include <tqcursor.h>
#include <tqheader.h>
-#include <stylesheet.h>
+#include <tqstylesheet.h>
#include <tqtimer.h>
#include <klocale.h>
@@ -64,7 +64,7 @@ KNHeaderView::KNHeaderView(TQWidget *parent, const char *name) :
setColumnAlignment( mPaintInfo.sizeCol, TQt::AlignRight );
setColumnAlignment( mPaintInfo.scoreCol, TQt::AlignRight );
// due to our own column text squeezing we need to repaint on column resizing
disconnect( header(), TQT_SIGNAL(sizeChange(int, int, int)) );
connect( header(), TQT_SIGNAL(sizeChange(int, int, int)),
TQT_SLOT(slotSizeChanged(int, int, int)) );
@@ -534,7 +534,7 @@ TQDragObject* KNHeaderView::dragObject()
void KNHeaderView::slotSizeChanged( int section, int, int newSize )
{
- viewport()->repaint( header()->sectionPos(section), 0, newSize, visibleHeight(), false);
+ viewport()->tqrepaint( header()->sectionPos(section), 0, newSize, visibleHeight(), false);
}
@@ -601,14 +601,14 @@ void KNHeaderViewToolTip::maybeTip( const TQPoint &p )
if ( !item->showToolTip( column ) )
return;
- const TQRect itemRect = listView->itemRect( item );
- if ( !itemRect.isValid() )
+ const TQRect tqitemRect = listView->tqitemRect( item );
+ if ( !tqitemRect.isValid() )
return;
const TQRect headerRect = listView->header()->sectionRect( column );
if ( !headerRect.isValid() )
return;
- tip( TQRect( headerRect.left(), itemRect.top(), headerRect.width(), itemRect.height() ),
+ tip( TQRect( headerRect.left(), tqitemRect.top(), headerRect.width(), tqitemRect.height() ),
TQStyleSheet::escape( item->text( column ) ) );
}
@@ -64,7 +64,7 @@ KNHeaderView::KNHeaderView(TQWidget *parent, const char *name) :
setColumnAlignment( mPaintInfo.sizeCol, TQt::AlignRight );
setColumnAlignment( mPaintInfo.scoreCol, TQt::AlignRight );
- // due to our own column text squeezing we need to repaint on column resizing
+ // due to our own column text squeezing we need to tqrepaint on column resizing
disconnect( header(), TQT_SIGNAL(sizeChange(int, int, int)) );
connect( header(), TQT_SIGNAL(sizeChange(int, int, int)),